package Acme::Automatix;

use 5.006;
use strict;
use warnings;

=head1 NAME

Acme::Automatix - The release of Acme::Automatix is automatix!

=head1 VERSION

Version 0.04

=cut

our $VERSION = '0.04';


=head1 SYNOPSIS

Quick summary of what the module does...

Nothing!

It is used as a demo of the github action L<upload-to-cpan|https://github.com/thibaultduponchelle/upload-to-cpan>

See how it is L<automatically released|https://github.com/thibaultduponchelle/Acme-Automatix/blob/master/.github/workflows/build-and-upload.yml>

=head1 AUTHOR

Thibault Duponchelle, C<< <thibault.duponchelle at gmail.com> >>

=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2021 by Thibault Duponchelle.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)


=cut

1; # End of Acme::Automatix
